View source: R/graph_from_schedule.R
| graph_from_schedule | R Documentation |
Takes a list of continuous-time movement descriptions for each individual in a network and returns an undirected, weighted 'igraph' graph where edge weights are the proportion of time a dyad spent co-located at a patch.
graph_from_schedule(schedule)
schedule |
object from simulate_schedule() |
an undirected, weighted 'igraph' graph
obj <- simulate_schedule(n_animals = 15,
n_groups = 3,
time_to_leave = 5,
time_to_return = 2,
travel_time = c(0.001, 0.2),
sampling_duration = 20,
simulator = "independent")
g <- graph_from_schedule(schedule = obj)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.